@@ -76,15 +76,10 @@ class insert:
         settings = load_or_create_instance_settings()
         engine = settings.db_engine()
 
-        if str(root).startswith("s3://"):
-            storage_type = "s3"
-        elif str(root).startswith("gs://"):
-            storage_type = "gs"
-        else:
-            storage_type = "local"
-
         with sqm.Session(engine) as session:
-            storage = schema_core.storage(root=root, region=region, type=storage_type)
+            storage = schema_core.storage(
+                root=root, region=region, type=settings.storage.type
+            )
             session.add(storage)
             session.commit()
             session.refresh(storage)
