@@ -19,10 +19,11 @@ from ._settings_load import (
 )
 from ._settings_save import save_instance_settings
 from ._settings_store import settings_dir
+from ._setup_storage import get_storage_region
 
 
 def configure_schema_wetlab(schema_modules):
-    if "retro" in schema_modules:
+    def _no_biosample_techsample():
         file_loc = lnschema_core.__file__.replace("core", "wetlab")
         with open(file_loc, "r") as f:
             content = f.read()
@@ -32,6 +33,9 @@ def configure_schema_wetlab(schema_modules):
             )
             f.write(content)
 
+    if any([i in schema_modules for i in {"retro", "swarm"}]):
+        _no_biosample_techsample()
+
 
 def update_db(isettings, usettings):
     insert_if_not_exists.user(usettings.email, usettings.id, usettings.handle)
@@ -101,6 +105,10 @@ def setup_instance_db():
             import lnschema_retro  # noqa
 
             msg += ", retro"
+        if schema_modules is not None and "swarm" in schema_modules:
+            import maren.schema  # noqa
+
+            msg += ", swarm"
         logger.info(f"{msg}.")
         SQLModel.metadata.create_all(isettings.db_engine())
         isettings._update_cloud_sqlite_file()
@@ -155,19 +163,7 @@ def init(
 
     # setup storage
     instance_settings.storage_dir = setup_storage_dir(storage)
-    storage_root_str = str(instance_settings.storage_dir)
-    storage_region = None
-    if storage_root_str.startswith("s3://"):
-        import boto3
-
-        response = boto3.client("s3").get_bucket_location(
-            Bucket=storage_root_str.replace("s3://", "")
-        )
-        # returns `None` for us-east-1
-        # returns a string like "eu-central-1" etc. for all other regions
-        storage_region = response["LocationConstraint"]
-
-    instance_settings.storage_region = storage_region
+    instance_settings.storage_region = get_storage_region(instance_settings.storage_dir)
 
     # setup _config
     instance_settings._dbconfig = dbconfig
@@ -176,7 +172,7 @@ def init(
 
     # setup schema
     if schema is not None:
-        known_modules = ["bionty", "wetlab", "bfx", "retro"]
+        known_modules = ["bionty", "wetlab", "bfx", "retro", "swarm"]
         validated_schema = []
         for module in known_modules:
             if module in schema:
